'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.StartDynamo = StartDynamo;
exports.SaveChanges = SaveChanges;
exports.Push = Push;

var _initializationType = require('./initialization-type');

var _logger = require('./services/logger');

var _logger2 = _interopRequireDefault(_logger);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const process = require('child_process');


let runCommand = (args, secure) => {
    if (!secure) {
        (0, _logger2.default)("Running command: docker " + args.join(' '));
    } else {
        (0, _logger2.default)("Running docker command");
    }
    return new Promise((resolve, reject) => {
        process.execFile("docker", args, (err, out) => {
            if (err) {
                (0, _logger2.default)(err);
                reject(err);
            } else {
                (0, _logger2.default)(out);
                resolve(out);
            }
        });
    });
};

function StartDynamo(options) {

    return runCommand(["pull", "chagedorn/initialize-local-dynamo"]).then(() => {
        let port = 8000;

        if (options.port) {
            port = options.port;
        }

        let args = ["run", "-d", "-p", port + ":" + port, "chagedorn/initialize-local-dynamo", "-port", port];

        if (options.InitializationType === _initializationType.InitializationType.SharedDb) {
            args.push("-sharedDb");
        }

        return runCommand(args);
    });
};

function SaveChanges(repository, tag) {

    return runCommand(["ps", "-lq"]).then(container => {
        container = container.replace('\n', '');
        return runCommand(["commit", container, repository + ":" + tag]);
    });
};

function Push(username, password, repository, tag) {
    return runCommand(["login", "-u", username, "-p", password], true).then(container => runCommand(["push", repository + ":" + tag]));
};